#
# spec file for package python-stomp.py
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-stomp.py
Version:        6.0.0
Release:        bp156.3.2
Summary:        Python STOMP client
License:        Apache-2.0
URL:            https://github.com/jasonrbriggs/stomp.py
Source0:        https://files.pythonhosted.org/packages/source/s/stomp.py/stomp.py-%{version}.tar.gz
# using github archive for docs
Source1:        https://github.com/jasonrbriggs/stomp.py/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docopt >= 0.6.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Python client library for accessing messaging servers (such as ActiveMQ, Apollo or RabbitMQ) using the STOMP protocol versions 1.0, 1.1 and 1.2. It can also be run as a standalone, command-line client for testing.

%prep
%setup -q -n stomp.py-%{version}
%setup -q -n stomp.py-%{version} -D -b 1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/stomp
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative stomp

%postun
%python_uninstall_alternative stomp

%files %{python_files}
%doc README CHANGELOG
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/stomp

%changelog
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Feb 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 6.0.0:
  * Update to not allow a null (None) listener when calling set_listener (minor code "smell" tidy up)
  * Change get_ssl call in connect to be consistent with transport method
  * Add a sleep to the heartbeat loop
  * Minor change to make quote-use more consistent (replace single with double in most places)
  * Change build to use [Python Poetry](https://python-poetry.org/)
  * Test coverage improvement
  * Threading fix (is_alive) - https://github.com/jasonrbriggs/stomp.py/issues/286
* Sat Jan 18 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 5.0.1:
  * Fix logging simplification code (should not be logging to root appender - https://github.com/jasonrbriggs/stomp.py/issues/275)
* Wed Jan  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- dropped Python 2 support, not supported by the package
- update to version 5.0.0:
  * Fix for credentials exposure (https://github.com/jasonrbriggs/stomp.py/pull/244)
  * Check for ``STOMP_SKIP_HOSTNAME_SCAN`` environment variable before extending ``LOCALHOST_NAMES``
  * Remove python2 backwards compatibility
  * Update dockerfile for better local testing
  * Fix docker and travis setup, so there are consistent builds both locally and via CI
  * Drop deprecated start/stop methods from connection (issue https://github.com/jasonrbriggs/stomp.py/issues/257)
  * Fix for missing return in get_ssl (https://github.com/jasonrbriggs/stomp.py/pull/258)
  * Clear heartbeat event after heartbeat loop ends (https://github.com/jasonrbriggs/stomp.py/pull/260)
  * Update listener to move receive/message_received/heartbeat_received vars inside the 'with' blocks (https://github.com/jasonrbriggs/stomp.py/pull/252)
  * Simplify logging calls
  * Tidy up listeners (correct the behaviour of TestListener)
  * Fix problem with double-disconnect notification (ihttps://github.com/jasonrbriggs/stomp.py/issues/245)
  * Add facility for PrintingListener to write to log rather than print statements
* Thu Apr 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.1.22
  * Infinite retry attempts
  * Terminate heartbeat thread on shutdown
  * Remove unused wait_on_receipt parameter
  * Reduce verbosity in logging to not include headers unless debug
  level is turned on (potential security issue)
  * Fix for disconnect receipt usage in transport
  * Add __enter__/__exit__ to Connection so it can be used as a
  context
  * Additional ssl options
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Jul  7 2018 sebix+novell.com@sebix.at
- update to version 4.1.20:
  * Fix for deadlock issue (https://github.com/jasonrbriggs/stomp.py/issues/197)
  * Fix for encoding issue (https://github.com/jasonrbriggs/stomp.py/issues/195)
  * Fix for reconnect issue (https://github.com/jasonrbriggs/stomp.py/issues/202)
* Sun Feb 18 2018 sebix+novell.com@sebix.at
- initial package for version 4.1.20
